==> frodoio-0.9.4.tgz: package/test/integration/index.spec.js <==
var expect = require('chai').expect;
var sinon = require('sinon');
var Etcd = require('node-etcd');
var Frodo = require('../../src/index');
var Q = require('q');

describe('Frodo integration tests', function () {
  var frodo;

  beforeEach(function (done) {
    frodo = new Frodo({ context: 'integration', lazy: true });
    frodo.etcd.rmdir('integration', { recursive: true }).fin(function () {
      frodo.init().then(function () {
        done();
      }, function (err) {
        console.log(JSON.stringify(err));
        done(err);
      });
    });
  });

  afterEach(function (done) {
    frodo.close().then(done);
  });


  describe('#servers, #addServer', function () {
    it('Should get all servers', function (done) {
      var watcher = frodo.etcd.watcher('integration/hosts/done');
      frodo.addServer('first').then(function () {
        frodo.addServer('second').then(function () {
          frodo.addServer('done');
        });
      });
      watcher.on('change', function (changed) {
        frodo.servers().then(function (servers) {
          expect(servers[0]).to.eql('first');
          expect(servers[1]).to.eql('second');
          watcher.stop();
          done();
        }).done();
      });
    });
  });

  describe('#init', function () {
    it('Should get all servers on init', function (done) {
      var watcher = frodo.etcd.watcher('integration/hosts/done');
      var otherFrodo;
      frodo.addServer('first').then(function () {
        otherFrodo = new Frodo({ context: 'integration' });
        otherFrodo.ready.then(function () {
          return otherFrodo.addServer('done');
        }).done();
      });

      watcher.on('change', function (changed) {
        return frodo.servers().then(function (servers) {
          expect(servers.length).to.lte(2);
          expect(servers[0]).to.equal('first');
          watcher.stop();
          otherFrodo.close();
          done();
        }).done();
      });
    })
  })

  describe('#removeServer', function () {
    it('Should remove servers', function (done) {
      var watcher = frodo.etcd.watcher('integration/hosts/done');
      frodo.addServer('first').then(function () {
        frodo.removeServer('first').then(function () {
          frodo.addServer('second').then(function () {
            frodo.addServer('done');
          });
        })
      });

      watcher.on('change', function (changed) {
        return frodo.servers().then(function (servers) {
          expect(servers[0]).to.equal('second');
          expect(servers[1]).to.not.equal('first');
          watcher.stop();
          done();
        }).done();
      });
    });

    it('Should handle failed on removal of not existing server', function (done) {
      var watcher = frodo.etcd.watcher('integration/hosts/done');
      frodo.removeServer('foo').fail(function () {
        frodo.addServer('done');
      }).done();

      watcher.on('change', function (changed) {
        return frodo.servers().then(function (servers) {
          expect(servers.length).to.lte(1);
          expect(servers[0]).to.not.equal('foo');
          watcher.stop();
          done();
        }).done();
      });
    });

    it ('Should updated when changing hosts from other server', function (done) {
      var watcher = frodo.etcd.watcher('integration/hosts/done');
      var otherFrodo = new Frodo({ context: 'integration' });

      otherFrodo.ready.then(function () {
        return otherFrodo.addServer('first');
      }).then(function () {
        return otherFrodo.addServer('second');
      }).then(function () {
        return otherFrodo.removeServer('first');
      }).then(function () {
        return otherFrodo.addServer('done');
      }).done();

      watcher.on('change', function (changed) {
        return frodo.servers().then(function (servers) {
          expect(servers.length).to.lte(2);
          expect(servers[0]).to.equal('second');
          expect(servers[1]).to.not.equal('first');
          watcher.stop();
          otherFrodo.close();
          done();
        }).done();
      });
    })

  });
});

==> frodoio-3.1.0.tgz: package/test/integration/index.spec.js <==
var expect = require('chai').expect;
var sinon = require('sinon');
var Etcd = require('node-etcd');
var Frodo = require('../../src/index');
var Q = require('q');

describe('Frodo integration tests', function () {
  var frodo;

  beforeEach(function (done) {
    frodo = new Frodo({ context: 'integration', lazy: true });
    frodo.etcd.rmdir('integration', { recursive: true }).fin(function () {
      frodo.init().then(function () {
        done();
      }, function (err) {
        console.log(JSON.stringify(err));
        done(err);
      });
    });
  });

  afterEach(function (done) {
    frodo.close().then(done);
  });
  var pid = process.pid;

  describe('#servers, #addServer', function () {
    it('Should get all servers', function (done) {
      var watcher = frodo.etcd.watcher('integration/hosts/done:' + pid);
      frodo.addServer('first').then(function () {
        frodo.addServer('second').then(function () {
          frodo.addServer('done');
        });
      });
      watcher.on('change', function (changed) {
        frodo.servers().then(function (servers) {
          expect(servers[0]).to.eql('first');
          expect(servers[1]).to.eql('second');
          watcher.stop();
          done();
        }).done();
      });
    });
  });

  describe('#init', function () {
    it('Should get all servers on init', function (done) {
      var watcher = frodo.etcd.watcher('integration/hosts/done:' + pid);
      var otherFrodo;
      frodo.addServer('first').then(function () {
        otherFrodo = new Frodo({ context: 'integration' });
        otherFrodo.ready.then(function () {
          return otherFrodo.addServer('done');
        }).done();
      });

      watcher.on('change', function (changed) {
        return frodo.servers().then(function (servers) {
          expect(servers.length).to.lte(2);
          expect(servers[0]).to.equal('first');
          watcher.stop();
          otherFrodo.close();
          done();
        }).done();
      });
    })
  })

  describe('#removeServer', function () {
    it('Should remove servers', function (done) {
      var watcher = frodo.etcd.watcher('integration/hosts/done:' + pid);
      frodo.addServer('first').then(function () {
        frodo.removeServer('first').then(function () {
          frodo.addServer('second').then(function () {
            frodo.addServer('done');
          });
        })
      });

      watcher.on('change', function (changed) {
        return frodo.servers().then(function (servers) {
          expect(servers[0]).to.equal('second');
          expect(servers[1]).to.not.equal('first');
          watcher.stop();
          done();
        }).done();
      });
    });

    it('Should handle failed on removal of not existing server', function (done) {
      var watcher = frodo.etcd.watcher('integration/hosts/done:' + pid);
      frodo.removeServer('foo').fail(function () {
        frodo.addServer('done');
      }).done();

      watcher.on('change', function (changed) {
        return frodo.servers().then(function (servers) {
          expect(servers.length).to.lte(1);
          expect(servers[0]).to.not.equal('foo');
          watcher.stop();
          done();
        }).done();
      });
    });

    it('Should updated when changing hosts from other server', function (done) {
      var watcher = frodo.etcd.watcher('integration/hosts/done:' + pid);
      var otherFrodo = new Frodo({ context: 'integration' });

      otherFrodo.ready.then(function () {
        return otherFrodo.addServer('first');
      }).then(function () {
        return otherFrodo.addServer('second');
      }).then(function () {
        return otherFrodo.removeServer('first');
      }).then(function () {
        return otherFrodo.addServer('done');
      }).done();

      watcher.on('change', function (changed) {
        return frodo.servers().then(function (servers) {
          expect(servers.length).to.lte(2);
          expect(servers[0]).to.equal('second');
          expect(servers[1]).to.not.equal('first');
          watcher.stop();
          otherFrodo.close();
          done();
        }).done();
      });
    })

    it('Should delete all servers with same key', function (done) {
      var firstWatcher = frodo.etcd.watcher('integration/hosts/first-done:' + pid);
      var secondWatcher = frodo.etcd.watcher('integration/hosts/second-done:' + pid);
      var otherFrodo = new Frodo({ context: 'integration' });
      // Adding 2 firsts -> 1 second -> 1 first -> checking that all have been added -> remove all instances of first -> check that only host named second is there.
      otherFrodo.ready.then(function () {
        return otherFrodo.addServer('first', { id: 1 });
      }).then(function () {
        return otherFrodo.addServer('first', { id: 2 });
      }).then(function () {
        return otherFrodo.addServer('second');
      }).then(function () {
        return otherFrodo.addServer('first', { id: 3 });
      }).then(function () {
        return otherFrodo.addServer('first-done');
      }).done();

      firstWatcher.on('change', function () {
        frodo.servers().then(function (servers) {
          expect(servers[0]).to.equal('first');
          expect(servers[1]).to.equal('first');
          expect(servers[2]).to.equal('second');
          expect(servers[3]).to.equal('first');
        }).then(function () {
          return otherFrodo.removeServer('first', { all: true });
        }).then(function () {
          return otherFrodo.addServer('second-done');
        }).done();
      });

      secondWatcher.on('change', function () {
        return Q.delay(30).then(function () {
          return frodo.servers().then(function (servers) {
            expect(servers[0]).to.equal('second');
            expect(servers[1]).to.not.equal('first');
            expect(servers[2]).to.not.equal('first');
            otherFrodo.close();
            done();
          });
        }).done();
      });
    })

  });
});
